@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_apigateway._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_s3._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-stack-resource-rename",
-    "0.0.6",
+    "0.0.8",
     __name__[0:-6],
-    "cdk-stack-resource-rename@0.0.6.jsii.tgz",
+    "cdk-stack-resource-rename@0.0.8.jsii.tgz",
 )
 
 __all__ = [
